# -*- coding: utf-8 -*-
"""Transform data sourced from pro-football-reference.com."""


# %% Imports
import pandas as pd
# TODO: consider this
# import dask.dataframe as dd


# %% Functions


# %% Script
if __name__ == '__main__':
    pass
