# -*- coding: utf-8 -*-


# %% Imports
# %%% 3rd Pary
import pytest

# %%% User Defined
from nfetl.processes.extract import get_url_data, get_update
from nfetl._config import _config as config
from nfetl.processes.transform import *


# %% Functions


# %% Script
if __name__ == '__main__':
    pass
